@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.api_api import ApiApi
+#   from .api.companies_api import CompaniesApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,7 +14,9 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
-from openapi_client.api.api_api import ApiApi
 from openapi_client.api.companies_api import CompaniesApi
+from openapi_client.api.machinecounter_api import MachinecounterApi
 from openapi_client.api.machines_api import MachinesApi
+from openapi_client.api.schema_api import SchemaApi
+from openapi_client.api.states_api import StatesApi
 from openapi_client.api.telemetry_api import TelemetryApi
