@@ -11,4 +11,6 @@
 
 from openapi_client.model.company import Company
 from openapi_client.model.machine import Machine
+from openapi_client.model.machine_counter_reading import MachineCounterReading
+from openapi_client.model.machine_state import MachineState
 from openapi_client.model.telemetry_value import TelemetryValue
